@@ -47,7 +47,9 @@ class ColorInput(TextInput):  # lgtm [py/missing-call-to-init]
     """
     Color input widget.
 
-    .. note:: This widget implements the same transformations as TextInput.
+    .. note::
+
+        This widget implements the same transformations as TextInput.
 
     :param title: Color input title
     :type title: str
