@@ -1471,6 +1471,7 @@ class TextInput(Widget):
 
         updated = False
         events = self._merge_events(events)  # Extend events with custom events
+        rect = self.get_rect()
 
         for event in events:  # type: pygame.event.Event
 
@@ -1728,15 +1729,17 @@ class TextInput(Widget):
                 self._block_copy_paste = False
                 self._key_is_pressed = False
 
-            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP:
-                if self._rect.collidepoint(*event.pos) and \
+            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONUP and \
+                    event.button in (1, 2, 3):  # Don't consider the mouse wheel (button 4 & 5)
+                if rect.collidepoint(*event.pos) and \
                         self.get_selected_time() > 1.5 * self._keyrepeat_mouse_interval_ms:
                     self._absolute_origin = getattr(event, 'origin', self._absolute_origin)
                     self._selection_active = False
                     self._check_mouse_collide_input(event.pos)
                     self._cursor_ms_counter = 0
 
-            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONDOWN:
+            elif self.mouse_enabled and event.type == pygame.MOUSEBUTTONDOWN and \
+                    event.button in (1, 2, 3):  # Don't consider the mouse wheel (button 4 & 5)
                 if self.get_selected_time() > self._keyrepeat_mouse_interval_ms:
                     self._absolute_origin = getattr(event, 'origin', self._absolute_origin)
                     if self._selection_active:
@@ -1749,7 +1752,7 @@ class TextInput(Widget):
             elif self.touchscreen_enabled and event.type == pygame.FINGERUP:
                 window_size = self.get_menu().get_window_size()
                 finger_pos = (event.x * window_size[0], event.y * window_size[1])
-                if self._rect.collidepoint(finger_pos) and \
+                if rect.collidepoint(*finger_pos) and \
                         self.get_selected_time() > 1.5 * self._keyrepeat_touch_interval_ms:
                     self._absolute_origin = getattr(event, 'origin', self._absolute_origin)
                     self._selection_active = False
